@@ -6,8 +6,8 @@ __all__ = ["__author__",
            "Aleatoryous",
            "coinToBinary"]
 
-__author__ = "Diego Ramirez"
-__version__ = "0.0.4"
+__author__ = "Diego Ramirez (dr01191115@gmail.com) @DiddiLeija"
+__version__ = "0.0.6"
 
 
 import random
@@ -38,13 +38,15 @@ class Aleatoryous():
                  "getmode",
                  "changemode"]
     dict = {}
-    #it = None
+    __it = 0
 
     def __init__(self, mode="aleatory.coin", extras=None):
         if mode == "aleatory.coin":
             self.__mode = "Coin"
+            self.__it = 2
         elif mode == "aleatory.dice":
             self.__mode = "Dice"
+            self.__it = 6
         elif mode == "aleatory.roulette":
             self.__mode = "Roulette"
             if extras is not None:
@@ -56,6 +58,7 @@ class Aleatoryous():
             for i in range(len(self.parser)):
                 self.it = i + 1
                 self.dict[self.parser[i]] = self.it
+            self.__it = len(self.parser)
         else:
             raise InitError(IE.modal_bug())
         #self.cache = ""
@@ -92,25 +95,9 @@ class Aleatoryous():
 
 
     def first_5_basic(self):
+        "New since 0.0.6: Faster operations"
         for time in [1, 2, 3, 4, 5]:
-            if self.__mode == "Coin":
-                self.tot = random.randint(0, 1)
-                if self.tot == 1:
-                    self.lst.append("Head")
-                elif self.tot == 0:
-                    self.lst.append("Tails")
-                else:
-                    self.lst.append(None)
-            elif self.__mode == "Dice":
-                self.tot = random.randint(1, 6)
-                self.lst.append(self.tot)
-            elif self.__mode == "Roulette":
-                self.tot = random.randint(1, len(self.dict))
-                for k, v in self.dict.items():
-                    if v == self.tot:
-                        self.lst.append(k)
-            else:
-                pass
+            self.lst.append(self.single())
 
 
     def first_5(self):
@@ -139,22 +126,36 @@ class Aleatoryous():
             self.first_5_basic()
         return self.lst
 
-    def first_given(self, how):
+
+    def first_given(self, how, /, repeat=True):
+        "New since 0.0.6: You can iterate with no repetition"
         self.refresh()
         if not isinstance(how, "int"):
-            raise InitError(f"Expected integers, % given" % type(how))
-        tmp = []
-        for time in range(how):
-            tmp.append(time + 1)
-        for time in tmp:
-            self.first_5_basic()
+            raise SyntaxError(f"Expected integers, %s given" % type(how))
+        if not isinstance(rep, "bool"):
+            raise SyntaxError(f"At parameter 'repeat', you must enter True or False, not %s" % repeat)
+        else:
+            if self.__mode == "Coin" and repeat is False:
+                raise SyntaxError(f"'No-repetition' feature is not available for 'aleatory.dice' objects")
+            if not repeat and how > self.__it:
+                raise SyntaxError(f"Cannot give more than %s iterations without repetitions." % self.__it)
+        if repeat:
+            for time in range(how):
+                self.lst.append(self.single())
+        else:
+            possible = self.single()
+            if possible in self.lst:
+                continue
+            self.lst.append(possible)
         return self.lst
 
+
     def getmode(self):
         "New since 0.0.3: get the private mode."
         self.refresh()
         return self.__modetype
 
+
     def changemode(self, mode, extras=None):
         "New since 0.0.3: restart the object with a new mode."
         self.__init__(mode, extras)
@@ -165,7 +166,7 @@ class Aleatoryous():
     def __dir__(self):
         return self.__methods
     def __str__(self):
-        return "Aleatoryous" + " " + self.__modetype
+        return "Aleatoryous " + self.__modetype
 
 
 def coinToBinary(res):
