@@ -7,4 +7,4 @@ def KI_bug():
     return f"Program Interrupted by User..."
 
 def modal_bug():
-    return f"__init__() Method Invalid Syntax (Unexpected mode given)"
+    return f"__init__() Invalid Syntax (Unexpected parameter given: mode)"
